Re: [PATCH] x86/hyperv: Rename hv_isolation_type_snp/en_snp() to isol_type_snp_paravisor/enlightened()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



On 7/25/2023 11:22 PM, Vitaly Kuznetsov wrote:
Tianyu Lan <ltykernel@xxxxxxxxx> writes:

From: Tianyu Lan <tiala@xxxxxxxxxxxxx>

Rename hv_isolation_type_snp and hv_isolation_type_en_snp()
to make them much intuitiver.

Suggested-by: Vitaly Kuznetsov <vkuznets@xxxxxxxxxx>
Signed-off-by: Tianyu Lan <tiala@xxxxxxxxxxxxx>

Thanks for the patch! A few comments below ...

---
This patch is based on the patchset "x86/hyperv: Add AMD sev-snp
enlightened guest support on hyperv" https://lore.kernel.org/lkml/
20230718032304.136888-3-ltykernel@xxxxxxxxx/T/.

  arch/x86/hyperv/hv_init.c       |  6 +++---
  arch/x86/hyperv/ivm.c           | 17 +++++++++--------
  arch/x86/include/asm/mshyperv.h |  8 ++++----
  arch/x86/kernel/cpu/mshyperv.c  | 12 ++++++------
  drivers/hv/connection.c         |  2 +-
  drivers/hv/hv.c                 | 16 ++++++++--------
  drivers/hv/hv_common.c          | 10 +++++-----
  include/asm-generic/mshyperv.h  |  4 ++--
  8 files changed, 38 insertions(+), 37 deletions(-)

diff --git a/arch/x86/hyperv/ivm.c b/arch/x86/hyperv/ivm.c
index 2eda4e69849d..2911c2525ed5 100644
--- a/arch/x86/hyperv/ivm.c
+++ b/arch/x86/hyperv/ivm.c
@@ -591,24 +591,25 @@ bool hv_is_isolation_supported(void)
  	return hv_get_isolation_type() != HV_ISOLATION_TYPE_NONE;
  }
-DEFINE_STATIC_KEY_FALSE(isolation_type_snp);
+DEFINE_STATIC_KEY_FALSE(isol_type_snp_paravisor_flag);
/*
  * hv_isolation_type_snp - Check system runs in the AMD SEV-SNP based
   * isolation VM.
   */
-bool hv_isolation_type_snp(void)
+bool isol_type_snp_paravisor(void)
@@ -591,24 +591,25 @@ bool hv_is_isolation_supported(void)
/*
- * hv_isolation_type_snp - Check system runs in the AMD SEV-SNP based
+ * isol_type_snp_paravisor - Check system runs in the AMD SEV-SNP based
   * isolation VM.
   */


I think that it would be better to keep 'hv_' prefix here for two reasons:
...


Agree. Will update.

Thanks.




[Index of Archives]     [Linux Kernel]     [Kernel Newbies]     [x86 Platform Driver]     [Netdev]     [Linux Wireless]     [Netfilter]     [Bugtraq]     [Linux Filesystems]     [Yosemite Discussion]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Samba]     [Device Mapper]

  Powered by Linux